// ==UserScript==
// @name           Pardus Nav Bar Clock
// @description    Inserts a selection of clocks into the navigation bar of the main screen showing times that events happen in Pardus. These clocks can be switched on/off by editing the script - instructions inside.
// @author         Miche (Orion) / Sparkle (Artemis) ...based on v4.2 code originally from Rhindon http://userscripts.org/scripts/show/13641
// @include        http://*.pardus.at/menu.php
// @version        2.6
// ==/UserScript==

if (document.URL.search('pardus.at/menu.php') > -1) {

	// this contains the list of possible clocks that can be selected to display
	var pardusNavClock = {
		'localTime': false, 'GMTTime': false, 'serverReset': false,
		'APTick': false, 'buildingTick': false, 'planetTick': false,
		'starbaseTick': false, 'monsterTick': false, 'eMatterTick': false
	};


/*
	 *****************************************************************************************************************************\
		You might want to update some of the variables below that control what clocks display and exactly how they display etc
	*******************************************************************************************************************************
*/
	
/*
	This variable determines how far along the top navigation the main clocks will be inserted.
	Integers between 0 and 9 are valid here.
	
	var positionAlongMenuToInsertPardusClock = 0; // display on the left
	var positionAlongMenuToInsertPardusClock = 4; // display in the middle
	var positionAlongMenuToInsertPardusClock = 9; // display on the right
	
*/
	
	var positionAlongMenuToInsertPardusClock = 4;
	
	
/*
	Choose which clocks you want to display and what order they appear on the screen my modifying the 
	"clocksToDisplay" array. This is a comma seperated list of the individual clock names.
	Several pre-made variations are presented below to describe how you can manage what is displayed.
		
	Save the following "master copy" for if you need to change the clocks you see (it shows all the clocks).
	
	var clocksToDisplay = ['localTime', 'GMTTime', 'serverReset', 'APTick', 'buildingTick', 'planetTick', 'starbaseTick', 'monsterTick', 'eMatterTick']; // show all possible clocks
	

	If you don't want a particular clock to show, remove it from the array. This example shows only 5 of the clocks:
	
	var clocksToDisplay = ['GMTTime', 'APTick', 'buildingTick', 'planetTick', 'starbaseTick']; // Show five clocks in the menu bar
	

	You can change the order they are displayed on screen by simply changing the order they appear in the array:
	
	var clocksToDisplay = ['APTick', 'buildingTick', 'starbaseTick', 'planetTick', 'GMTTime']; // Show 5 clocks in a different order than before
	

	You can even display just a single clock should you so desire:
	
	var clocksToDisplay = ['GMTTime']; // Just show the GMT/UTC clock
	
*/
	
	var clocksToDisplay = ['localTime', 'GMTTime', 'serverReset', 'APTick', 'buildingTick', 'planetTick', 'starbaseTick', 'monsterTick'];


/*
	Include extra information about how frequently each clock ticks when you hover the mouse over a clock.
	This is on (true) by default and you can turn if off by setting the variable below to false.
	
	var showExtraInformationWhenHoveringOnLabels = false; // do not show extra information when hovering on a clock
	var showExtraInformationWhenHoveringOnLabels = true; // show information about a clock when hovering over it
	
*/
	
	var showExtraInformationWhenHoveringOnLabels = true;
	

/*
	Show the number of seconds for each clock. This allows you to see that the clock is ticking but may
	be distracting for some people. Set this variable to false to only show minutes and hours.
		
	var showSecondsInTheClocks = false;
	var showSecondsInTheClocks = true;
	
*/
	
	var showSecondsInTheClocks = true;
	
	
/*
	Rather than turn off seconds, you could alter the frequency that the clock updates to reduce the ticking onscreen.

	var FREQUENCY_OF_CLOCK_TICK = 1000; // tick every 1000 milliseconds (every second)
	var FREQUENCY_OF_CLOCK_TICK = 5000; // tick every 5000 milliseconds (every 5 seconds)
	var FREQUENCY_OF_CLOCK_TICK = 10000; // tick every 10000 milliseconds (every 10 seconds)

*/

	var FREQUENCY_OF_CLOCK_TICK = 1000; // tick every 1000 milliseconds (every second)



/*
	 *****************************************************************************************************************************\
		Here you can control the internationalisation of the clock. This is useful if English is not your preferred language,
		or if you just don't like the text being used and prefer something else.
		
		You set the language to use by changing the	pardusNavClock.language variable.
		
		Current values for pardusNavClock.language are 'en' (English), 'fr' (French), 'de' (German)

	 ******************************************************************************************************************************
		The default setting is included to allow you to "reset" everything if things get out of control and start breaking.

		pardusNavClock.language = 'en';

	 ******************************************************************************************************************************
*/

	pardusNavClock.language = 'en';


/*
	 *****************************************************************************************************************************\
		The internationalisation data below allows support for multiple languages. Current support for English, French, German.
		Please get in touch if you are interested in translating this into other languages.
	 ******************************************************************************************************************************
*/
	pardusNavClock.i18nData = {
		// English (en) language translations (default)
		'en':{
			'clockLabelNames': {
				'localTime':'Your Time',
				'GMTTime':'GMT/UTC',
				'serverReset':'Server Reset',
				'APTick':'APs',
				'buildingTick':'Building',
				'planetTick':'Planet',
				'starbaseTick':'Starbase',
				'monsterTick':'Monsters',
				'eMatterTick':'E Matter'
			},
			'errorMsg':{
				'title':'Pardus Nav Menu Clock Error - No clocks are set to display',
				'description':'See the documentation inside the script for details'
			},
			'extraInfoLabels':{
				'localTime':'Your local time',
				'GMTTime':'Pardus uses GMT as a time reference',
				'serverReset':'Pardus servers restart at 0530 GMT daily',
				'APTick':'APs tick every 6 mins',
				'buildingTick':'Buildings tick every 6 hrs',
				'planetTick':'Planets tick every 3 hrs',
				'starbaseTick':'Starbases tick every 3 hrs',
				'monsterTick':'Monsters tick every 9 mins',
				'eMatterTick':'Jeff Foam ticks every 90 mins'
			}
		}
	}

	// French (fr) language translations
	pardusNavClock.i18nData['fr'] = {
		'clockLabelNames': {
			'localTime':'Votre temps',
			'GMTTime':'GMT / UTC',
			'serverReset':'Reset Server',
			'APTick':'AP',
			'buildingTick':'B&acirc;timent',
			'planetTick':'Planet',
			'starbaseTick':'Starbase',
			'monsterTick':'Monstres',
			'eMatterTick':'E Mati&egrave;re'
		},
		'errorMsg': {
			'title':'Pardus Nav Menu Clock Erreur - Aucun horloges configur&eacute;es pour afficher',
			'description':'Voir la documentation dans du script pour informations',
		},
		'extraInfoLabels': {
			'localTime':'Votre heure locale',
			'GMTTime':'Pardus utilise GMT comme une r&eacute;f&eacute;rence de temps',
			'serverReset':'Pardus red&eacute;marrer les serveurs &agrave; 0530 GMT tous les jours',
			'APTick':'AP cocher toutes les 6 minutes',
			'buildingTick':'B&acirc;timents cocher toutes les 6 heures',
			'planetTick':'Plan&egrave;tes tick toutes les 3 heures',
			'starbaseTick':'Bases stellaires tick toutes les 3 heures',
			'monsterTick':'Monstres cocher toutes les 9 minutes',
			'eMatterTick':'Jeff mousse tiques toutes les 90 min'
		}
	}
	
	// German (de) language translations
	pardusNavClock.i18nData['de'] = {
		'clockLabelNames': {
			'localTime':'Ortszeit',
			'GMTTime':'GMT / UTC',
			'serverReset':'Server-Reset',
			'APTick':'APs',
			'buildingTick':'Bauen',
			'planetTick':'Planet',
			'starbaseTick':'Starbase',
			'monsterTick':'Monsters',
			'eMatterTick':'E Matter'
		},
		'errorMsg':{
			'title':'Pardus Nav Menu Clock Fehler - Keine Uhren sind so eingestellt, Display',
			'description':'In der Dokumentation im Skript f&uuml;r Details'
		},
		'extraInfoLabels': {
			'localTime':'Ihre lokale Zeit',
			'GMTTime':'Pardus setzt GMT als Zeitreferenz',
			'serverReset':'Pardus Server an 0530 GMT starten t&auml;glich',
			'APTick':'APs ticken alle 6 Minuten',
			'buildingTick':'Geb&auml;ude Zecke alle 6 Stunden',
			'planetTick':'Planeten kreuzen alle 3 Stunden',
			'starbaseTick':'Sternenbasen ticken alle 3 Stunden',
			'monsterTick':'Monsters ticken alle 9 Minuten',
			'eMatterTick':'Jeff Foam Zecken alle 90 Min.'
		}
	}



/*
	 *****************************************************************************************************************************\
		The next section allows configuration of the look and feel of the clock. You probably won't need to change the
		settings here - but it is preferable to it here so that you can easily carry your changes into future versions.
		
	 ******************************************************************************************************************************
		The default settings are included to allow you to "reset" everything if things get out of control and start breaking.

		var paddingSpaceAboveClock = 8; 										// 8 pixels of space above the clock
		var fontSizeForClockLabels = 11; 										// font size of 11px for the upper clock labels
		var fontSizeForClocks = 12; 											// font size of 12px for the lower clocks themselves
		var fontFamilyForClockLabels = 'Verdana,Arial,Helvetica,sans-serif';	// use Verdana as the main font for clock labels
		var fontFamilyForClocks = 'Verdana,Arial,Helvetica,sans-serif';			// use Verdana as the main font for clocks

	 ******************************************************************************************************************************
*/


/*
	Depending on the size and family of the font being used (and even the browser and operating system of computer), you may need
	to adjust the gap between the clock and the top of the screen to make the clocks appear vertically centered within nav bar.
	
	Change this number (positive integers only) to increase or decrease this gap.

	var paddingSpaceAboveClock = 8; // 8 pixels of space above the clock

*/

	var paddingSpaceAboveClock = 8;


/*
	You can control the size of the clock labels and the clocks themselves using the two variables below. Be aware that using the
	same size for the clock labels and the clocks will likely display as different sizes unless both are using the same font family.
	
	You can use this to squeeze more clocks into a narrow screen.

	var fontSizeForClockLabels = 11; // font size of 11px for the upper clock labels
	var fontSizeForClocks = 12; // font size of 11px for the lower clocks themselves

*/

	var fontSizeForClockLabels = 11;
	var fontSizeForClocks = 12;


/*
	You can control the font for the clock labels and the clocks using the two variables below. These contain the CSS font family definitions
	to be used. You may want to change these if you have a customised layout, require a narrow font for space considerations or you just have
	a particular font that you prefer to use.
	
	var fontFamilyForClockLabels = 'Verdana,Arial,Helvetica,sans-serif'; // font-family:Verdana,Arial,Helvetica,sans-serif;
	var fontFamilyForClocks = 'Verdana,Arial,Helvetica,sans-serif'; // font-family:Verdana,Arial,Helvetica,sans-serif;

	Place your prefered font at the beginning and it will be used if it is available... otherwise it goes on to the next etc.
	In this example	the font Trebuchet MS is to be used for the clock labels (if it is available).

	var fontFamilyForClockLabels = 'Trebuchet MS,Verdana,Arial,Helvetica,sans-serif';
	
*/

	var fontFamilyForClockLabels = 'Verdana,Arial,Helvetica,sans-serif';
	var fontFamilyForClocks = 'Verdana,Arial,Helvetica,sans-serif';


/*
	 *****************************************************************************************************************************\
		Unless you are confident with your Javascript and Greasemonkey abilities, it's probably best to stop at this stage
	*******************************************************************************************************************************
*/
	
	// Initialise the clock and insert if into the page before starting it ticking.
	function initialisePardusNavClock() {
		var navTable = document.getElementsByTagName('table')[1];
		var tableCells = navTable.getElementsByTagName('td');
		var cell = tableCells[0];
		var insertIndex = Math.abs(positionAlongMenuToInsertPardusClock * 2);
		if (insertIndex >= tableCells.length) {
			cell = tableCells[tableCells.length-1];
		} else if (insertIndex < tableCells.length) {
			cell = tableCells[insertIndex];
		}
		var html = getHTMLForAllClocks();
		cell.style.cssText = 'color:#CDCED8;text-align:center;vertical-align:top;';
		cell.innerHTML = html;
		if (typeof clocksToDisplay != 'undefined') {
			tickPardusNavClock();
		}
	};
	
	
	// Update each clock that is enabled - called every second to function like a real clock.
	function tickPardusNavClock() {
		var theCurrentTime = new Date;
		var minutes = theCurrentTime.getMinutes();
		var seconds = theCurrentTime.getSeconds();
		var hours = theCurrentTime.getHours();
	
		// local time
		if (pardusNavClock.localTime) {
			updateHTML("tim", formatTime(hours, minutes, seconds));
		}
	
		// pardus uses GMT for reference
		if (pardusNavClock.GMTTime) {
			var _gmtHours = theCurrentTime.getUTCHours();
			updateHTML("gmt", formatTime(_gmtHours, minutes, seconds));
		}
	
		// we now count down so switch our variables over
		seconds = 59 - seconds;

		// APs tick every 6 minutes
		if(pardusNavClock.APTick) {
			var _apMinutes = 5 - minutes % 6;
			updateHTML("ap", formatTime('x', _apMinutes, seconds));
			setColor("ap", "000100", "000010");
		}
	
		// monster tick happens every 9 minutes
		if (pardusNavClock.monsterTick) {
			var _monstMinutes = 8 - minutes % 9;
			updateHTML("mon", formatTime('x', _monstMinutes, seconds));
			setColor("mon", "000200", "000030");
		}
	
		// exotic matter ticks every 90 minutes
		if(pardusNavClock.eMatterTick) {
			var _emHours = 0;
			var _emMinutes = 89 - minutes % 60;
			if (_emMinutes > 60) {
				_emMinutes = _emMinutes - 60;
				_emHours = _emHours + 1;
			}
			updateHTML("em", formatTime(_emHours, _emMinutes, seconds));
			setColor("em", "000500", "000200");
		}


		if(pardusNavClock.buildingTick || pardusNavClock.planetTick || pardusNavClock.starbaseTick) {
			// starbase, building and planet ticks happen at 25 minutes past the hour
			theCurrentTime = new Date();
			var _tmpMinutes = theCurrentTime.getMinutes();
			_tmpMinutes -= 25;
			if (_tmpMinutes < 0) {
				_tmpMinutes += 60;
				theCurrentTime.setHours(theCurrentTime.getHours() - 1);
			}
			theCurrentTime.setMinutes(_tmpMinutes);
			minutes = 59-theCurrentTime.getMinutes();
			seconds = 59-theCurrentTime.getSeconds();
			theCurrentTime.setHours(theCurrentTime.getUTCHours() + 5);
	
			// starbase ticks happen every 3 hours starting at hour 00 GMT/UTC
			if(pardusNavClock.starbaseTick) {
				var _hoursPerTick = 3;
				var _hoursOffset = 1;
				hours = _hoursPerTick - 1 - ((theCurrentTime.getHours() + _hoursOffset) % _hoursPerTick);
				updateHTML("sb", formatTime(hours, minutes, seconds));
				setColor("sb", "001000", "000500");
			}
	
			// building ticks happen every 6 hours starting at hour 01 GMT/UTC
			if(pardusNavClock.buildingTick) {
				var _hoursPerTick = 6;
				var _hoursOffset = 0;
				hours = _hoursPerTick - 1 - ((theCurrentTime.getHours() + _hoursOffset) % _hoursPerTick);
				updateHTML("bui", formatTime(hours, minutes, seconds));
				setColor("bui", "001000", "000500");
			}
	
			// planet ticks happen every 3 hours starting at hour 02 GMT/UTC
			if(pardusNavClock.planetTick) {
				var _hoursPerTick = 3;
				var _hoursOffset = 2;
				hours = _hoursPerTick - 1 - ((theCurrentTime.getHours() + _hoursOffset) % _hoursPerTick);
				updateHTML("pl", formatTime(hours, minutes, seconds));
				setColor("pl", "001000", "000500");
			}
		}

		// server reset happens every 24 hours starting at 0530 GMT/UTC
		// first get the minutes set correctly
		if(pardusNavClock.serverReset) {
			theCurrentTime = new Date();
			var _tmpMinutes = theCurrentTime.getMinutes();
			_tmpMinutes -= 30;
			if (_tmpMinutes < 0) {
				_tmpMinutes += 60;
				theCurrentTime.setHours(theCurrentTime.getHours() - 1);
			}
			theCurrentTime.setMinutes(_tmpMinutes);
			minutes = 59-theCurrentTime.getMinutes();
			seconds = 59-theCurrentTime.getSeconds();
			// now the hours
			var UTCHours = theCurrentTime.getUTCHours();
			var _hoursPerTick = 24;
			var _hoursOffset = 5;
			hours = (_hoursPerTick - (UTCHours - _hoursOffset) % _hoursPerTick - 1) % 24;
			updateHTML("reset", formatTime(hours, minutes, seconds));
			setColor("reset", "001000", "000500");
		}

/*
		// another way to get the server reset countdown working...
		if(pardusNavClock.serverReset) {
			// set up the minutes
			var _now = new Date;
			var _tmpMinutes = _now.getMinutes() - 30;
			if (_tmpMinutes < 30) {
				_tmpMinutes += 60;
				theCurrentTime.setUTCHours(theCurrentTime.getUTCHours()-1);
			}
			theCurrentTime.setMinutes(_tmpMinutes);
			minutes = 59 - theCurrentTime.getMinutes();
			// now the hours
			var UTCHours = theCurrentTime.getUTCHours();
			var _hoursPerTick = 24;
			var _hoursOffset = 5;
			hours = (_hoursPerTick - (UTCHours - _hoursOffset) % _hoursPerTick - 1) % 24;
			updateHTML("reset", formatTime(hours, minutes, seconds));
			setColor("reset", "001000", "000500");
		}
*/

		// run this method again in the interval supplied (in milliseconds) - make it tick
		setTimeout(tickPardusNavClock, FREQUENCY_OF_CLOCK_TICK);
	};
	
	
	// Gather all the HTML for the clocks to be inserted when requested by initialisePardusNavClock()
	function getHTMLForAllClocks() {
		var upperClockHTML = '<table cellpadding="0" cellspacing="0" border="0" style="width:100%;margin-top:' + paddingSpaceAboveClock+ 'px;"><thead><tr' + (showExtraInformationWhenHoveringOnLabels? ' style="cursor:help;font-family:' + fontFamilyForClockLabels + ';font-size:' + fontSizeForClockLabels + 'px;"' : '') + '>';
		var lowerClockHTML = '<tbody><tr style="font-family:' + fontFamilyForClocks + ';font-size:' + fontSizeForClocks + 'px;' + (showExtraInformationWhenHoveringOnLabels? 'cursor:help;' : '') + '">';
		if (typeof clocksToDisplay != 'undefined' && clocksToDisplay.length) {
			for (var loop=0; loop<clocksToDisplay.length; loop++) {
				pardusNavClock[clocksToDisplay[loop]] = true;
				var clockHTML = getHTMLFragmentForAClock(clocksToDisplay[loop]);
				upperClockHTML += clockHTML.top; lowerClockHTML += clockHTML.bottom;
			}
		} else {
			upperClockHTML += '<td>Pardus Nav Menu Clock Error - No clocks are set to display</td>';
			lowerClockHTML += '<td>See the documentation inside the Pardus Nav Menu Clock script for details</td>';
		}
		upperClockHTML += '</tr></thead>';
		lowerClockHTML += '</tr></tbody></table>';
		return upperClockHTML + lowerClockHTML;
	};
	
	
	// Return the upper and lower HTML fragment for a requested clock when requested by getHTMLForAllClocks()
	function getHTMLFragmentForAClock(clock) {
		var result = {'top':'','bottom':''};
		switch (clock) {
			case 'localTime' :
				result.top = '<td nowrap id="msg_timlbl"' + (showExtraInformationWhenHoveringOnLabels? ' title="' + getLocalisedMsg('extraInfoLabels.localTime') + '"' : '') + '>' + getLocalisedMsg('clockLabelNames.localTime') + '</td>';
				result.bottom = '<td><span id="msg_tim"'  + (showExtraInformationWhenHoveringOnLabels? ' title="' + getLocalisedMsg('extraInfoLabels.localTime') + '"' : '') + '>88:88:88</span></td>';
				break;
			case 'GMTTime' :
				result.top = '<td nowrap id="msg_gmtlbl"' + (showExtraInformationWhenHoveringOnLabels? ' title="' + getLocalisedMsg('extraInfoLabels.GMTTime') + '"' : '') + '>' + getLocalisedMsg('clockLabelNames.GMTTime') + '</td>';
				result.bottom = '<td><span id="msg_gmt"'  + (showExtraInformationWhenHoveringOnLabels? ' title="' + getLocalisedMsg('extraInfoLabels.GMTTime') + '"' : '') + '>88:88:88</span></td>';
				break;
			case 'serverReset' :
				result.top = '<td nowrap id="msg_resetlbl"' + (showExtraInformationWhenHoveringOnLabels? ' title="' + getLocalisedMsg('extraInfoLabels.serverReset') + '"' : '') + '>' + getLocalisedMsg('clockLabelNames.serverReset') + '</td>';
				result.bottom = '<td><span id="msg_reset"'  + (showExtraInformationWhenHoveringOnLabels? ' title="' + getLocalisedMsg('extraInfoLabels.serverReset') + '"' : '') + '>88:88:88</span></td>';
				break;
			case 'APTick' :
				result.top = '<td nowrap id="msg_aplbl"' + (showExtraInformationWhenHoveringOnLabels? ' title="' + getLocalisedMsg('extraInfoLabels.APTick') + '"' : '') + '>' + getLocalisedMsg('clockLabelNames.APTick') + '</td>';
				result.bottom = '<td><span id="msg_ap"'  + (showExtraInformationWhenHoveringOnLabels? ' title="' + getLocalisedMsg('extraInfoLabels.APTick') + '"' : '') + '>88:88</span></td>';
				break;
			case 'buildingTick' :
				result.top = '<td nowrap id="msg_builbl"' + (showExtraInformationWhenHoveringOnLabels? ' title="' + getLocalisedMsg('extraInfoLabels.buildingTick') + '"' : '') + '>' + getLocalisedMsg('clockLabelNames.buildingTick') + '</td>';
				result.bottom = '<td><span id="msg_bui"'  + (showExtraInformationWhenHoveringOnLabels? ' title="' + getLocalisedMsg('extraInfoLabels.buildingTick') + '"' : '') + '>88:88:88</span></td>';
				break;
			case 'planetTick' :
				result.top = '<td nowrap id="msg_pllbl"' + (showExtraInformationWhenHoveringOnLabels? ' title="' + getLocalisedMsg('extraInfoLabels.planetTick') + '"' : '') + '>' + getLocalisedMsg('clockLabelNames.planetTick') + '</td>';
				result.bottom = '<td><span id="msg_pl"'  + (showExtraInformationWhenHoveringOnLabels? ' title="' + getLocalisedMsg('extraInfoLabels.planetTick') + '"' : '') + '>88:88:88</span></td>';
				break;
			case 'starbaseTick' :
				result.top = '<td nowrap id="msg_sblbl"' + (showExtraInformationWhenHoveringOnLabels? ' title="' + getLocalisedMsg('extraInfoLabels.starbaseTick') + '"' : '') + '>' + getLocalisedMsg('clockLabelNames.starbaseTick') + '</td>';
				result.bottom = '<td><span id="msg_sb"'  + (showExtraInformationWhenHoveringOnLabels? ' title="' + getLocalisedMsg('extraInfoLabels.starbaseTick') + '"' : '') + '>88:88:88</span></td>';
				break;
			case 'monsterTick' :
				result.top = '<td nowrap id="msg_monlbl"' + (showExtraInformationWhenHoveringOnLabels? ' title="' + getLocalisedMsg('extraInfoLabels.monsterTick') + '"' : '') + '>' + getLocalisedMsg('clockLabelNames.monsterTick') + '</td>';
				result.bottom = '<td><span id="msg_mon"'  + (showExtraInformationWhenHoveringOnLabels? ' title="' + getLocalisedMsg('extraInfoLabels.monsterTick') + '"' : '') + '>88:88</span></td>';
				break;
			case 'eMatterTick' :
				result.top = '<td nowrap id="msg_emlbl"' + (showExtraInformationWhenHoveringOnLabels? ' title="' + getLocalisedMsg('extraInfoLabels.eMatterTick') + '"' : '') + '>' + getLocalisedMsg('clockLabelNames.eMatterTick') + '</td>';
				result.bottom = '<td><span id="msg_em"'  + (showExtraInformationWhenHoveringOnLabels? ' title="' + getLocalisedMsg('extraInfoLabels.eMatterTick') + '"' : '') + '>88:88:88</span></td>';
				break;
		}
		return result;
	};
	
	
/*
	 *****************************************************************************************************************************\
		Helper and utility methods used by the main code above
	*******************************************************************************************************************************
*/
	
	// Given a lookup key consisting of the message section and the message name this will
	// return the text localised to the current language as set in this script.
	// If no translation is available it will default back to the English version.
	function getLocalisedMsg(key) {
		var retVal = key;
		try {
			var _sectkey = key.split('.')[0];
			var _valkey = key.split('.')[1];
			if (pardusNavClock.i18nData[pardusNavClock.language][_sectkey][_valkey]) {
				retVal = pardusNavClock.i18nData[pardusNavClock.language][_sectkey][_valkey];
			} else {
				retVal = pardusNavClock.i18nData['en'][_sectkey][_valkey];
			}
		} catch(ex) {
			GM_log('\ngetLocalisedMsg() was unable to parse the key, ' + key);
		}
		return retVal;
	};

	
	// Facade used by tickPardusNavClock() to set the colour of a single label/timer column
	function setColor(id, yrate, rrate) {
		changeColor("msg_" + id, yrate, rrate);
	};
	
	
	// Facade to update the HTML for a particular clock with supplied text
	function updateHTML(id, text) {
		if(document.getElementById("msg_" + id)) document.getElementById("msg_" + id).innerHTML = text;
	};
	
	
	// Set the colour of a single label/timer column based on how close it is to ending
	function changeColor(id, yrate, rrate) {
		var x = document.getElementById(id);
		var y = document.getElementById(id + "lbl");
		var timer = Number(document.getElementById(id).innerHTML.replace(':', '').replace(':', ''));
		yrate = Number(yrate);
		rrate = Number(rrate);
		if (timer > yrate) {
			x.style.color = '#CDCED8';
			y.style.color = '#CDCED8';
		}
		if (timer <= yrate && timer > rrate) {
			x.style.color = 'yellow';
			y.style.color = 'yellow';
		}
		if (timer <= rrate) {
			if (id == 'msg_ap') {
				x.style.color = 'green';
				y.style.color = 'green';
			} else {
				x.style.color = 'red';
				y.style.color = 'red';
			}
		}
	};
	
	
	// Format the time output into hh:mm:ss by default
	// if 'x' is passed in as the first variable then it formats the time as mm:ss
	function formatTime(hours, minutes, seconds) {
		var timeSeparator = ':';
		var result = hours == 'x' ? padNumber(minutes) : hours + timeSeparator + padNumber(minutes);
		if (showSecondsInTheClocks) result += timeSeparator + padNumber(seconds)
		return result;
	};
	
	
	// Used by formatTime() to give single digits a leading zero.
	function padNumber(number) {
		return (number > 9) ? '' + number : '0' + number;
	};

/*
	 *****************************************************************************************************************************\
		Finally, we invoke our intialisation code - secure that everything is now loaded in readiness...
		
		This course of action was a direct result of noticing that I was unable to trigger any kind of loaded window event
		with any reliability. The injected codefile would work perfectly normally when the menu.php file is requested
		directly - but was unable to work on a normal load of the document in a frame. That was using addEventListener.
		
		This mechanism works. I am happy to stick with it :) 
	*******************************************************************************************************************************
*/

	initialisePardusNavClock();

}
